@@ -176,6 +176,7 @@ INSTALLED_APPS = (
     "allauth.socialaccount.providers.trainingpeaks",
     "allauth.socialaccount.providers.trello",
     "allauth.socialaccount.providers.tumblr",
+    "allauth.socialaccount.providers.tumblr_oauth2",
     "allauth.socialaccount.providers.twentythreeandme",
     "allauth.socialaccount.providers.twitch",
     "allauth.socialaccount.providers.twitter",
@@ -255,6 +256,7 @@ SOCIALACCOUNT_PROVIDERS = {
 }
 
 ACCOUNT_LOGIN_BY_CODE_ENABLED = True
+ACCOUNT_ADAPTER = "tests.common.adapters.AccountAdapter"
 
 HEADLESS_ONLY = True
 HEADLESS_FRONTEND_URLS = {
@@ -262,6 +264,7 @@ HEADLESS_FRONTEND_URLS = {
     "account_reset_password": "/spa/password/reset/",
     "account_reset_password_from_key": "/spa/password/reset/{key}/",
     "account_signup": "/spa/signup",
+    "socialaccount_login_error": "/spa/error",
 }
 HEADLESS_SERVE_SPECIFICATION = True
 
