@@ -172,6 +172,7 @@ INSTALLED_APPS = (
     "allauth.socialaccount.providers.trainingpeaks",
     "allauth.socialaccount.providers.trello",
     "allauth.socialaccount.providers.tumblr",
+    "allauth.socialaccount.providers.tumblr_oauth2",
     "allauth.socialaccount.providers.twentythreeandme",
     "allauth.socialaccount.providers.twitch",
     "allauth.socialaccount.providers.twitter",
@@ -224,6 +225,8 @@ PASSWORD_HASHERS = [
 ]
 
 
+ACCOUNT_ADAPTER = "tests.common.adapters.AccountAdapter"
+
 SOCIALACCOUNT_QUERY_EMAIL = True
 SOCIALACCOUNT_PROVIDERS = {
     "openid_connect": {
